Orange Data Mining Library
==========================

Tutorial
--------

This is a gentle introduction on scripting in `Orange <http://orange.biolab.si>`_ , a Python 3 data mining library. We here assume you have already downloaded and installed Orange from its `github repository <https://github.com/biolab/orange3>`_ and have a working version of Python. In the command line or any Python environment, try to import Orange. Below, we used a Python shell::

   % python
   >>> import Orange
   >>> Orange.version.version
   '3.2.dev0+8907f35'
   >>>

If this leaves no error and warning, Orange and Python are properly installed and you are ready to continue with the Tutorial.

.. toctree::
   :maxdepth: 3

   tutorial/data
   tutorial/classification
   tutorial/regression
..   ensembles
..   python-learners



Reference
---------

Available classes and methods.

.. toctree::
   :maxdepth: 2

   reference/data
   reference/preprocess
   reference/classification
   reference/regression
   reference/clustering
   reference/distance
   reference/evaluation
   reference/projection
   reference/misc

